"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toJsonRule = void 0;
const json_path_to_dot_notation_1 = require("./json-path-to-dot-notation");
const OperatorMapping = {
    // string and numeric
    equal: "===",
    notEqual: "!==",
    // numeric
    lessThan: "<",
    lessThanInclusive: "<=",
    greaterThan: ">",
    greaterThanInclusive: ">=",
    // array
    in: "in",
    notIn: "in",
    contains: "in",
    doesNotContain: "in",
};
function toJsonPath({ fact, path }) {
    if (!path) {
        return fact;
    }
    return `${fact}.${(0, json_path_to_dot_notation_1.jsonPathToDotNotation)(path)}`;
}
function isTopLevelCondition(condition) {
    return "all" in condition || "any" in condition;
}
function transformNested(input) {
    if (isTopLevelCondition(input)) {
        return transformTopLevel(input);
    }
    const operator = input.operator;
    const rule = {
        [OperatorMapping[operator]]: [{ var: toJsonPath(input) }, input.value],
    };
    if (operator === "notIn") {
        return { "!": [rule] };
    }
    if (["contains", "doesNotContain"].includes(operator)) {
        return {
            [operator === "contains" ? "some" : "none"]: [
                { var: toJsonPath(input) },
                { [OperatorMapping.equal]: [{ var: "" }, input.value] },
            ],
        };
    }
    return rule;
}
function transformTopLevel(input) {
    if ("all" in input) {
        return { and: input.all.map(transformNested) };
    }
    return { or: input.any.map(transformNested) };
}
function toJsonRule(input) {
    return transformTopLevel(input);
}
exports.toJsonRule = toJsonRule;
